==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/app/translations/qmmp_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Naar voren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Naar achteren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Begin met afspelen van huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Niet de afspeellijst leeghalen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pauzeer huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pauzeer als er wordt gespeeld, anders spelen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Stop huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Weergeef bestandskeuze venster</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Sluit applicatie</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Verander afspeelvolume (voorbeeld: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Toon/verberg programma</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Toon venster om bestanden toe te voegen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Toon venster om mappen toe te voegen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="350"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Gebruik: qmmp [opties] [bestanden]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="351"/>
        <source>Options:</source>
        <translation>Opties:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="355"/>
        <source>Don&apos;t start the application</source>
        <translation>Niet de applicatie starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="357"/>
        <source>Print version number and exit</source>
        <translation>Print versienummer en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="358"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Ideëen, patches, foutrapporten zenden naar forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="361"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="374"/>
        <source>QMMP version: %1</source>
        <translation>QMMP versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="375"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Gecompileerd met QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="376"/>
        <source>Using Qt version: %1</source>
        <translation>Gebruikt QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="379"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="356"/>
        <source>Display this text and exit</source>
        <translation>Toon deze tekst en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="95"/>
        <source>Unknown command</source>
        <translation>Onbekend commando</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/app/translations/qmmp_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Naar voren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Naar achteren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Begin met afspelen van huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Niet de afspeellijst leeghalen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pauzeer huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pauzeer als er wordt gespeeld, anders spelen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Stop huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Weergeef bestandskeuze venster</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Sluit applicatie</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Verander afspeelvolume (voorbeeld: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Toon/verberg programma</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Toon venster om bestanden toe te voegen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Toon venster om mappen toe te voegen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="373"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Gebruik: qmmp [opties] [bestanden]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="374"/>
        <source>Options:</source>
        <translation>Opties:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="380"/>
        <source>Start qmmp with the specified user interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="381"/>
        <source>List all available user interfaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="382"/>
        <source>Don&apos;t start the application</source>
        <translation>Niet de applicatie starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="384"/>
        <source>Print version number and exit</source>
        <translation>Print versienummer en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="386"/>
        <source>Home page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="387"/>
        <source>Development page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="388"/>
        <source>Bug tracker: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="393"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="406"/>
        <source>QMMP version: %1</source>
        <translation>QMMP versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="407"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Gecompileerd met QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Using Qt version: %1</source>
        <translation>Gebruikt QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="411"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>User Interfaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="383"/>
        <source>Display this text and exit</source>
        <translation>Toon deze tekst en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="109"/>
        <source>Unknown command</source>
        <translation>Onbekend commando</translation>
    </message>
</context>
</TS>
